export function createMemoryStorage(opts?: MemoryStorageOpts): MemoryStorage;
/**
 * A helper Storage implementation for testing when only using one server. For production use
 * Postgres or something persistent that other clients can also read.
 *
 * @implements {AbstractStorage}
 */
export class MemoryStorage implements AbstractStorage {
    /**
     * @param {MemoryStorageOpts} opts
     */
    constructor(opts: MemoryStorageOpts);
    /**
     * path := room.docid.referenceid
     * @type {Map<string, Map<string, Map<string, Uint8Array>>>}
     */
    docs: Map<string, Map<string, Map<string, Uint8Array>>>;
    populateDoc: ((room: string, docname: string) => Promise<Y.Doc | null>) | null;
    /**
     * @param {string} room
     * @param {string} docname
     * @param {Y.Doc} ydoc
     * @returns {Promise<void>}
     */
    persistDoc(room: string, docname: string, ydoc: Y.Doc): Promise<void>;
    /**
     * @param {string} room
     * @param {string} docname
     * @return {Promise<{ doc: Uint8Array, references: Array<string> } | null>}
     */
    retrieveDoc(room: string, docname: string): Promise<{
        doc: Uint8Array;
        references: Array<string>;
    } | null>;
    /**
     * This can be implemented by the storage provider for better efficiency. The state vector must be
     * updated when persistDoc is called. Otherwise, we pull the ydoc and compute the state vector.
     *
     * @param {string} room
     * @param {string} docname
     * @return {Promise<Uint8Array|null>}
     */
    retrieveStateVector(room: string, docname: string): Promise<Uint8Array | null>;
    /**
     * @param {string} room
     * @param {string} docname
     * @param {Array<string>} storeReferences
     * @return {Promise<void>}
     */
    deleteReferences(room: string, docname: string, storeReferences: Array<string>): Promise<void>;
    destroy(): Promise<void>;
}
export type AbstractStorage = import('../storage.js').AbstractStorage;
export type MemoryStorageOpts = {
    /**
     * Populate the doc if it doesn't exist yet in the database
     */
    populateDoc?: ((room: string, docname: string) => Promise<Y.Doc | null>) | undefined;
};
import * as Y from 'yjs';
//# sourceMappingURL=memory.d.ts.map